<?php
/**
 * Chiropractor Therapy functions and definitions
 *
 * @subpackage Chiropractor Therapy
 * @since 1.0
 */

/**
 * Change number or products per row to 3
 */
add_filter('loop_shop_columns', 'chiropractor_therapy_loop_columns', 999);
if (!function_exists('chiropractor_therapy_loop_columns')) {
	function chiropractor_therapy_loop_columns() {
		return 3;
	}
}

function chiropractor_therapy_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

function chiropractor_therapy_sanitize_checkbox( $input ) {
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

function chiropractor_therapy_sanitize_select( $input, $setting ){
    $input = sanitize_key($input);
    $choices = $setting->manager->get_control( $setting->id )->choices;
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

function chiropractor_therapy_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function chiropractor_therapy_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}

	$link = sprintf(
		'<div class="link-more text-center"><a href="%1$s" class="more-link py-2 px-4">%2$s</a></div>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Read More<span class="screen-reader-text"> "%s"</span>', 'chiropractor-therapy' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'chiropractor_therapy_excerpt_more' );

function chiropractor_therapy_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( "align-wide" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'chiropractor-therapy-featured-image', 2000, 1200, true );
	add_image_size( 'chiropractor-therapy-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'chiropractor-therapy' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style( array( 'assets/css/editor-style.css' ) );
}
add_action( 'after_setup_theme', 'chiropractor_therapy_setup' );

function chiropractor_therapy_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'chiropractor-therapy' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'chiropractor-therapy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'chiropractor-therapy' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'chiropractor-therapy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'chiropractor-therapy' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'chiropractor-therapy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'chiropractor-therapy' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'chiropractor-therapy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'chiropractor-therapy' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'chiropractor-therapy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'chiropractor-therapy' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'chiropractor-therapy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'chiropractor_therapy_widgets_init' );

//Enqueue scripts and styles.
function chiropractor_therapy_scripts() {

	require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );

	wp_enqueue_style(
		'outfit',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Outfit:wght@100;200;300;400;500;600;700;800;900&display=swap' ),
		array(),
		'1.0'
	);

	//Bootstarp
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri().'/assets/css/bootstrap.css' );

	// Theme stylesheet.
	wp_enqueue_style( 'chiropractor-therapy-style', get_stylesheet_uri() );

	wp_style_add_data('chiropractor-therapy-style', 'rtl', 'replace');

	// Theme Customize CSS.
	require get_parent_theme_file_path( 'inc/extra_customization.php' );
	wp_add_inline_style( 'chiropractor-therapy-style',$chiropractor_therapy_custom_style );

	//font-awesome
	wp_enqueue_style( 'font-awesome-style', get_template_directory_uri().'/assets/css/fontawesome-all.css' );

	//Owl Carousel CSS
	wp_enqueue_style( 'owl.carousel-style', get_template_directory_uri().'/assets/css/owl.carousel.css' );

	// Block Style
	wp_enqueue_style( 'chiropractor-therapy-block-style', esc_url( get_template_directory_uri() ).'/assets/css/blocks.css' );

	//Custom JS
	wp_enqueue_script( 'chiropractor-therapy-custom.js', get_theme_file_uri( '/assets/js/theme-script.js' ), array( 'jquery' ), true );

	//Nav Focus JS
	wp_enqueue_script( 'chiropractor-therapy-navigation-focus', get_theme_file_uri( '/assets/js/navigation-focus.js' ), array( 'jquery' ), true );

	//Superfish JS
	wp_enqueue_script( 'superfish-js', get_theme_file_uri( '/assets/js/jquery.superfish.js' ), array( 'jquery' ),true );

	//Bootstarp JS
	wp_enqueue_script( 'bootstrap-js', get_theme_file_uri( '/assets/js/bootstrap.js' ), array( 'jquery' ),true );

	//Owl Carousel JS
	wp_enqueue_script( 'owl.carousel-js', get_theme_file_uri( '/assets/js/owl.carousel.js' ), array( 'jquery' ),true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'chiropractor_therapy_scripts' );

function chiropractor_therapy_custom_courses() {
  add_meta_box( 'bn_meta', __( 'Courses Meta Feilds', 'chiropractor-therapy' ), 'chiropractor_therapy_meta_courses_callback', 'post', 'normal', 'high' );
}
if (is_admin()){
  add_action('admin_menu', 'chiropractor_therapy_custom_courses');
}

function chiropractor_therapy_meta_courses_callback( $post ) {
	wp_nonce_field( basename( __FILE__ ), 'chiropractor_therapy_courses_meta' );
		$bn_stored_meta = get_post_meta( $post->ID );
		$chiropractor_therapy_teacher = get_post_meta( $post->ID, 'chiropractor_therapy_teacher', true );
		$chiropractor_therapy_student = get_post_meta( $post->ID, 'chiropractor_therapy_student', true );
		$chiropractor_therapy_lesson = get_post_meta( $post->ID, 'chiropractor_therapy_lesson', true );
	?>
  	<div id="custom_meta_feilds">
    	<table id="list">
	      	<tbody id="the-list" data-wp-lists="list:meta">
				<tr id="meta-8">
					<td class="left">
						<?php esc_html_e( 'Teacher Name', 'chiropractor-therapy' )?>
					</td>
					<td class="left">
						<input type="text" name="chiropractor_therapy_teacher" id="chiropractor_therapy_teacher" value="<?php echo esc_attr($chiropractor_therapy_teacher); ?>" />
					</td>
				</tr>
				<tr id="meta-8">
					<td class="left">
						<?php esc_html_e( 'Count of students', 'chiropractor-therapy' )?>
					</td>
					<td class="left">
						<input type="text" name="chiropractor_therapy_student" id="chiropractor_therapy_student" value="<?php echo esc_attr($chiropractor_therapy_student); ?>" />
					</td>
				</tr>
				<tr id="meta-8">
					<td class="left">
						<?php esc_html_e( 'Count of lessons', 'chiropractor-therapy' )?>
					</td>
					<td class="left">
						<input type="text" name="chiropractor_therapy_lesson" id="chiropractor_therapy_lesson" value="<?php echo esc_attr($chiropractor_therapy_lesson); ?>" />
					</td>
				</tr>
	      	</tbody>
    	</table>
  	</div>
  <?php
}

function chiropractor_therapy_save( $post_id ) {
	if (!isset($_POST['chiropractor_therapy_courses_meta']) || !wp_verify_nonce( strip_tags( wp_unslash( $_POST['chiropractor_therapy_courses_meta']) ), basename(__FILE__))) {
  		return;
  	}

	if (!current_user_can('edit_post', $post_id)) {
		return;
	}
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
		return;
	}

	if( isset( $_POST[ 'chiropractor_therapy_teacher' ] ) ) {
		update_post_meta( $post_id, 'chiropractor_therapy_teacher', strip_tags( wp_unslash( $_POST[ 'chiropractor_therapy_teacher' ]) ) );
	}
	if( isset( $_POST[ 'chiropractor_therapy_student' ] ) ) {
		update_post_meta( $post_id, 'chiropractor_therapy_student', strip_tags( wp_unslash( $_POST[ 'chiropractor_therapy_student' ]) ) );
	}
	if( isset( $_POST[ 'chiropractor_therapy_lesson' ] ) ) {
		update_post_meta( $post_id, 'chiropractor_therapy_lesson', strip_tags( wp_unslash( $_POST[ 'chiropractor_therapy_lesson' ]) ) );
	}
}
add_action( 'save_post', 'chiropractor_therapy_save' );

function chiropractor_therapy_enqueue_admin_script( $hook ) {

	// Admin JS
	wp_enqueue_script( 'chiropractor-therapy-admin.js', get_theme_file_uri( '/assets/js/chiropractor-therapy-admin.js' ), array( 'jquery' ), true );

	wp_localize_script('chiropractor-therapy-admin.js', 'chiropractor_therapy_scripts_localize',
        array(
            'ajax_url' => esc_url(admin_url('admin-ajax.php'))
        )
    );
}
add_action( 'admin_enqueue_scripts', 'chiropractor_therapy_enqueue_admin_script' );

// Enqueue editor styles for Gutenberg
function chiropractor_therapy_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'chiropractor-therapy-block-editor-style', trailingslashit( esc_url ( get_template_directory_uri() ) ) . '/assets/css/editor-blocks.css' );
}
add_action( 'enqueue_block_editor_assets', 'chiropractor_therapy_block_editor_styles' );

function chiropractor_therapy_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'chiropractor_therapy_front_page_template' );

require get_parent_theme_file_path( '/inc/custom-header.php' );

require get_parent_theme_file_path( '/inc/template-tags.php' );

require get_parent_theme_file_path( '/inc/template-functions.php' );

require get_parent_theme_file_path( '/inc/customizer.php' );

require get_parent_theme_file_path( '/inc/dashboard/dashboard.php' );

function chiropractor_therapy_notice(){
    global $pagenow;
    if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
        wp_safe_redirect( admin_url("themes.php?page=chiropractor-therapy-guide-page") );
    }
}
add_action('after_setup_theme', 'chiropractor_therapy_notice');

function chiropractor_therapy_add_new_page() {
  $edit_page = admin_url().'post-new.php?post_type=page';
  echo json_encode(['page_id'=>'','edit_page_url'=> $edit_page ]);

  exit;
}
add_action( 'wp_ajax_chiropractor_therapy_add_new_page','chiropractor_therapy_add_new_page' );
