<?php
/**
 * The header for our theme
 *
 * @subpackage Chiropractor Therapy
 * @since 1.0
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php
	if ( function_exists( 'wp_body_open' ) ) {
	    wp_body_open();
	} else {
	    do_action( 'wp_body_open' );
	}
?>
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'chiropractor-therapy' ); ?></a>
	<?php if( get_theme_mod('chiropractor_therapy_theme_loader','') != ''){ ?>
		<div class="preloader">
			<div class="load">
		  		<hr/><hr/><hr/><hr/>
			</div>
		</div>
	<?php }?>
	<div id="page" class="site">
		<div class="wrap_figure py-2">
			<div class="container">
				<div class="row">
					<div class="col-lg-5 col-md-12 col-sm-12 align-self-center">
						<div class="row email-phone-box text-center text-md-left">
							<div class="col-lg-5 col-md-5 col-sm-5 align-self-center">
								<?php if( get_theme_mod('chiropractor_therapy_phone_text') != '' || get_theme_mod('chiropractor_therapy_phone_number') != '' ){ ?>
									<div class="row">
										<div class="col-lg-3 col-md-3 col-sm-3 align-self-center">
											<i class="fas fa-phone"></i>
										</div>
										<div class="col-lg-9 col-md-9 col-sm-9 align-self-center">
											<h4 class="mb-0"><?php echo esc_html(get_theme_mod('chiropractor_therapy_phone_text','')); ?></h4>
											<p class="mb-0"><?php echo esc_html(get_theme_mod('chiropractor_therapy_phone_number','')); ?></p>
										</div>
									</div>
								<?php }?>
							</div>
							<div class="col-lg-7 col-md-7 col-sm-7 align-self-center">
								<?php if( get_theme_mod('chiropractor_therapy_email_text') != '' || get_theme_mod('chiropractor_therapy_email_number') != '' ){ ?>
									<div class="row">
										<div class="col-lg-2 col-md-2 col-sm-2 align-self-center">
											<i class="far fa-envelope"></i>
										</div>
										<div class="col-lg-10 col-md-10 col-sm-10 align-self-center">
											<h4 class="mb-0"><?php echo esc_html(get_theme_mod('chiropractor_therapy_email_text','')); ?></h4>
											<p class="mb-0"><?php echo esc_html(get_theme_mod('chiropractor_therapy_email_number','')); ?></p>
										</div>
									</div>
								<?php }?>
							</div>
						</div>
					</div>
					<div class="col-lg-2 col-md-12 col-sm-12 align-self-center mb-2 mb-md-0">
						<div class="logo py-3 py-lg-0 text-center">
					        <?php if ( has_custom_logo() ) : ?>
			            		<?php the_custom_logo(); ?>
				            <?php endif; ?>
			              	<?php $blog_info = get_bloginfo( 'name' ); ?>
								<?php if( get_theme_mod('chiropractor_therapy_logo_title',true) != '' ){ ?>
					                <?php if ( ! empty( $blog_info ) ) : ?>
					                  	<?php if ( is_front_page() && is_home() ) : ?>
					                    	<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					                  	<?php else : ?>
				                      		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
				                  		<?php endif; ?>
					                <?php endif; ?>
								<?php } ?>
				                <?php
			                  		$description = get_bloginfo( 'description', 'display' );
				                  	if ( $description || is_customize_preview() ) :
				                ?>
								<?php if( get_theme_mod('chiropractor_therapy_logo_text',false) != '' ){ ?>
				                  	<p class="site-description">
				                    	<?php echo esc_html($description); ?>
				                  	</p>
								<?php } ?>
			              	<?php endif; ?>
					    </div>
					</div>
					<div class="col-lg-5 col-md-12 col-sm-12 align-self-center">
						<div class="row">
							<div class="col-lg-8 col-md-8 col-sm-8 col-7 align-self-center">
								<div class="linksbox text-md-left text-lg-right text-center">
									<?php if( get_theme_mod('chiropractor_therapy_facebook') != ''){ ?>
										<a href="<?php echo esc_url(get_theme_mod('chiropractor_therapy_facebook','')); ?>"><i class="fab fa-facebook-f"></i></a>
									<?php }?>
									<?php if( get_theme_mod('chiropractor_therapy_twitter') != ''){ ?>
										<a href="<?php echo esc_url(get_theme_mod('chiropractor_therapy_twitter','')); ?>"><i class="fab fa-twitter"></i></a>
									<?php }?>
									<?php if( get_theme_mod('chiropractor_therapy_linkdin') != ''){ ?>
										<a href="<?php echo esc_url(get_theme_mod('chiropractor_therapy_linkdin','')); ?>"><i class="fab fa-linkedin-in"></i></a>
									<?php }?>
									<?php if( get_theme_mod('chiropractor_therapy_youtube') != ''){ ?>
										<a href="<?php echo esc_url(get_theme_mod('chiropractor_therapy_youtube','')); ?>"><i class="fab fa-youtube"></i></a>
									<?php }?>
									<?php if( get_theme_mod('chiropractor_therapy_instagram') != ''){ ?>
										<a href="<?php echo esc_url(get_theme_mod('chiropractor_therapy_instagram','')); ?>"><i class="fab fa-instagram"></i></a>
									<?php }?>
								</div>
							</div>
							<div class="col-lg-4 col-md-4 col-sm-4 col-5 align-self-center">
								<?php if( get_theme_mod('chiropractor_therapy_header_quote_button') != '' || get_theme_mod('chiropractor_therapy_header_quote_link') != ''){ ?>
									<div class="button_wrap text-center text-md-right">
										<a href="<?php echo esc_url(get_theme_mod('chiropractor_therapy_header_quote_link','')); ?>"><?php echo esc_html(get_theme_mod('chiropractor_therapy_header_quote_button','')); ?></a>
									</div>
								<?php }?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<div class="menu_wrap py-2">
			<div class="container">
				<?php if(has_nav_menu('primary')){?>
					<div class="toggle-menu gb_menu text-md-right">
						<button onclick="chiropractor_therapy_gb_Menu_open()" class="gb_toggle p-2"><i class="fas fa-ellipsis-h"></i><p class="mb-0"><?php esc_html_e('Menu','chiropractor-therapy'); ?></p></button>
					</div>
				<?php }?>
				<?php get_template_part('template-parts/navigation/navigation'); ?>
			</div>
		</div>
